import {
  isSchemaObjectFlat
} from "./chunk-HIX6EHLQ.js";
import {
  valueToBoolean,
  valueToBooleanNotFalse,
  valueToInteger
} from "./chunk-QGUPJAJO.js";
import {
  fromCamelCase,
  toCamelCase
} from "./chunk-XOAKJFNZ.js";
import {
  objectFilter,
  objectMap
} from "./chunk-NEFIJY6U.js";
import {
  assert
} from "./chunk-CDC2UKQU.js";

// src/common/schema/env.ts
function parseSchemaEnv(schema, env = process?.env ?? {}, prefix = "") {
  assert(isSchemaObjectFlat(schema), "schema should be a flat object");
  const pl = prefix.length;
  if (pl > 0)
    env = objectFilter(env, (key) => key.startsWith(prefix));
  env = objectMap(env, (key, value) => {
    if (pl > 0)
      key = key.substring(pl);
    return [toCamelCase(key), value];
  });
  return objectMap(schema._object, (key, schema2) => {
    let value = env[toCamelCase(key)];
    if (schema2.type === "number") {
      value = valueToInteger(value, schema2._default);
    } else if (schema2.type === "boolean") {
      if (schema2._default === true)
        value = valueToBooleanNotFalse(value);
      else
        value = valueToBoolean(value, false);
    }
    return schema2.parse(value);
  });
}
function stringFromSchemaEnv(schema, prefix = "", commentOut = false) {
  assert(isSchemaObjectFlat(schema), "schema should be a flat object");
  const lines = [];
  objectMap(schema._object, (key, schema2) => {
    lines.push(`${commentOut ? "# " : ""}${prefix + fromCamelCase(key, "_").toUpperCase()}=${schema2._default ?? ""}`);
  });
  return lines.join("\n");
}

export {
  parseSchemaEnv,
  stringFromSchemaEnv
};
//# sourceMappingURL=chunk-WQJ47BZ7.js.map