import {
  deepEqual,
  deepMerge,
  deepStripUndefinedInPlace
} from "../../chunk-LAWEUL6N.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-4C3OMNSX.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-NEFIJY6U.js";
import {
  DefaultLogger
} from "../../chunk-XYJV3SSU.js";
import "../../chunk-JZBMDET5.js";
import "../../chunk-BFL67QFN.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-NNCJ3QL5.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AQUNU3KH.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/data/deep.spec.ts
var log = DefaultLogger("test:deep");
describe("deep", () => {
  it("should deep without self reference", () => {
    const sample = {
      a: 1
    };
    sample.b = sample;
    const sample2 = {
      a: 1
    };
    sample2.b = sample2;
    log("sample", sample);
    expect(deepEqual(sample, sample2)).toBe(false);
  });
  it("should compare arays", () => {
    const a = [1, 2, 3];
    const b = [3, 2, 1];
    expect(deepEqual(a, b)).toBe(false);
    const c = [3, 2, 1, 0];
    expect(deepEqual(a, c)).toBe(false);
  });
  it("should simple checks", () => {
    const value = new String("Hello");
    expect(typeof value === "object").toBe(true);
    expect(value.valueOf()).toBe("Hello");
    expect(new String(value).valueOf()).toBe("Hello");
  });
  it("should merge deep", () => {
    const a = {
      hello: {
        world: 42
      },
      before: {
        magic: 666
      }
    };
    const b = {
      hello: {
        world: -1,
        sea: "none"
      },
      other: {
        fish: 2
      }
    };
    const c = {
      other: {
        fish: 8
      }
    };
    const d = deepMerge(a, b, c);
    expect(d).toEqual({
      hello: {
        world: -1,
        sea: "none"
      },
      other: {
        fish: 8
      },
      before: {
        magic: 666
      }
    });
  });
  it("should strip undefined", () => {
    const sample = {
      hello: {
        world: -1,
        null1: null,
        undefined1: void 0,
        sea: "none"
      },
      undefined1: void 0,
      other: [
        {
          fish: 8,
          undefined1: void 0
        },
        void 0,
        null,
        "Hello"
      ],
      before: {
        magic: 666
      }
    };
    expect(JSON.stringify(sample, null, 2)).toMatchInlineSnapshot(`
      "{
        "hello": {
          "world": -1,
          "null1": null,
          "sea": "none"
        },
        "other": [
          {
            "fish": 8
          },
          null,
          null,
          "Hello"
        ],
        "before": {
          "magic": 666
        }
      }"
    `);
    expect(deepStripUndefinedInPlace(sample)).toMatchInlineSnapshot(`
      Object {
        "before": Object {
          "magic": 666,
        },
        "hello": Object {
          "null1": null,
          "sea": "none",
          "world": -1,
        },
        "other": Array [
          Object {
            "fish": 8,
            "undefined1": undefined,
          },
          null,
          "Hello",
        ],
      }
    `);
  });
});
//# sourceMappingURL=deep.spec.js.map