import {
  usePool
} from "../../chunk-BMPLIZZN.js";
import "../../chunk-MMY72EVL.js";
import "../../chunk-OSX4VQOR.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-OC6HNIEN.js";
import "../../chunk-BORRWM4T.js";
import "../../chunk-TRCJY7KG.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-K7Z2KDW3.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-XYJV3SSU.js";
import "../../chunk-JZBMDET5.js";
import "../../chunk-BFL67QFN.js";
import "../../chunk-MFUX7YH7.js";
import "../../chunk-MTV32UFZ.js";
import "../../chunk-NNCJ3QL5.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AQUNU3KH.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/exec/pool.spec.ts
describe("pool", () => {
  it("should execute some", async () => {
    const r = [];
    const pool = usePool({ maxParallel: 2 });
    const collectedEvents = [];
    pool.events.onAny((...args) => collectedEvents.push(args));
    expect(pool.progress.getFraction()).toBe(0);
    expect(pool.progress.getTotalUnits()).toBe(0);
    pool.enqueue(
      async () => {
        r.push("a");
        await sleep(10);
      },
      { id: "a" }
    );
    expect(pool.progress.getTotalUnits()).toBe(1);
    pool.enqueue(
      async (taskInfo) => {
        r.push("b");
        taskInfo?.setResolved(2);
        await sleep(1);
        taskInfo?.incResolved();
        await sleep(1);
        taskInfo?.incResolved();
        await sleep(10);
      },
      { id: "b", max: 5 }
    );
    pool.enqueue(
      async () => {
        r.push("c");
        await sleep(10);
      },
      { id: "c" }
    );
    pool.enqueue(
      async () => {
        r.push("d");
        await sleep(10);
      },
      { id: "d" }
    );
    pool.enqueue(
      async () => {
        r.push("dd");
        await sleep(10);
      },
      { id: "dd" }
    );
    pool.enqueue(
      async () => {
        r.push("e");
        await sleep(10);
      },
      { id: "e" }
    );
    const { cancel } = pool.enqueue(
      async () => {
        r.push("f");
        await sleep(10);
      },
      { id: "f" }
    );
    pool.cancel("dd");
    cancel();
    expect(r).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
      ]
    `);
    const { promise } = pool.enqueue(
      async () => {
        r.push("g");
        await sleep(10);
        return "g";
      },
      { id: "g" }
    );
    expect(pool.progress.getTotalUnits()).toBe(10);
    expect(pool.progress.toString()).toMatchInlineSnapshot(`
      "pool-0: 0 of 0 units, 20 %, cancel=false
        a: 0 of 1 units, 0 %, cancel=false
        b: 2 of 5 units, 40 %, cancel=false
        c: 0 of 1 units, 0 %, cancel=false
        d: 0 of 1 units, 0 %, cancel=false
        e: 0 of 1 units, 0 %, cancel=false
        g: 0 of 1 units, 0 %, cancel=false"
    `);
    expect(await promise).toBe("g");
    await pool.waitFinishAll();
    await sleep(1);
    expect(pool.progress.getTotalUnits()).toBe(0);
    expect(pool.progress.getCompletedUnits()).toBe(0);
    expect(pool.progress.getFraction()).toBe(0);
    expect(pool.progress.toString()).toMatchInlineSnapshot('"pool-0: 0 of 0 units, 0 %, cancel=false"');
    expect(r).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        "c",
        "d",
        "e",
        "g",
      ]
    `);
  });
  it("should respect group", async () => {
    const r = [];
    const pool = usePool({ maxParallel: 3 });
    const collectedEvents = [];
    pool.events.onAny((...args) => collectedEvents.push(args));
    pool.enqueue(
      async () => {
        r.push("ga");
        await sleep(10);
      },
      { id: "ga", group: "x" }
    );
    pool.enqueue(
      async () => {
        r.push("gb");
        await sleep(10);
      },
      { id: "gb", group: "x" }
    );
    pool.enqueue(
      async () => {
        r.push("gc");
        await sleep(10);
      },
      { id: "gc", group: "x" }
    );
    pool.enqueue(
      async () => {
        r.push("1");
        await sleep(10);
      },
      { id: "1" }
    );
    pool.enqueue(
      async () => {
        r.push("2");
        await sleep(10);
      },
      { id: "2" }
    );
    expect(r).toMatchInlineSnapshot(`
      Array [
        "ga",
        "1",
        "2",
      ]
    `);
    await pool.waitFinishAll();
    expect(r).toMatchInlineSnapshot(`
      Array [
        "ga",
        "1",
        "2",
        "gb",
        "gc",
      ]
    `);
    expect(collectedEvents).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
          1,
          0,
        ],
        Array [
          "didStart",
          "ga",
        ],
        Array [
          "didUpdate",
          2,
          0,
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
          3,
          0,
        ],
        Array [
          "didUpdate",
          4,
          0,
          4,
          0,
        ],
        Array [
          "didStart",
          "1",
        ],
        Array [
          "didUpdate",
          5,
          0,
          5,
          0,
        ],
        Array [
          "didStart",
          "2",
        ],
        Array [
          "didResolve",
          "ga",
          undefined,
        ],
        Array [
          "didUpdate",
          5,
          1,
          5,
          1,
        ],
        Array [
          "didStart",
          "gb",
        ],
        Array [
          "didResolve",
          "1",
          undefined,
        ],
        Array [
          "didUpdate",
          5,
          2,
          5,
          2,
        ],
        Array [
          "didResolve",
          "2",
          undefined,
        ],
        Array [
          "didUpdate",
          5,
          3,
          5,
          3,
        ],
        Array [
          "didResolve",
          "gb",
          undefined,
        ],
        Array [
          "didUpdate",
          5,
          4,
          5,
          4,
        ],
        Array [
          "didStart",
          "gc",
        ],
        Array [
          "didResolve",
          "gc",
          undefined,
        ],
        Array [
          "didUpdate",
          5,
          5,
          5,
          5,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=pool.spec.js.map